#
# spec file for package python-bugzillatools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oldpython python
Name:           python-bugzillatools
Version:        0.5.5
Release:        7.4
Summary:        Bugzilla CLI client, XML-RPC binding and VCS plugins
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/frasertweedale/bugzillatools
Source:         https://files.pythonhosted.org/packages/source/b/bugzillatools/bugzillatools-%{version}.tar.gz
# Port to Python3 from yet unreleased commits in the upstream repo
Patch0:         0001-Working-on-both-2.7-and-3.4.patch
# Some more py3k fixes
# https://github.com/rawrgulmuffins/bugzillatools/pull/26
Patch1:         no-bzrlib-py3k.patch
# PATCH-FIX-OPENSUSE python312.patch
Patch2:         python312.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
# We want to conflict even package literally called python-bugzilla
# without the python version number
Conflicts:      %{oldpython}-bugzilla
#Recommends:     bzr
# File conflict for /usr/bin/bugzilla:
Conflicts:      python-bugzilla
BuildArch:      noarch
%python_subpackages

%description
Provides a CLI program and Python library for interacting with the
Bugzilla_ bug tracking system, and plugins for version control
systems that enable interaction with Bugzilla installations.

%prep
%autosetup -p1 -n bugzillatools-%{version}

sed -i "/.bugzillarc.sample/d" setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/bugzilla
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest

%post
%python_install_alternative bugzilla

%postun
%python_uninstall_alternative bugzilla

%files %{python_files}
%doc CHANGES README.rst gpl-3.0.txt
%python_alternative %{_bindir}/bugzilla
%{python_sitelib}/bzlib
%{python_sitelib}/bzrlib
%{python_sitelib}/bugzillatools-%{version}-py%{python_version}.egg-info

%changelog
* Tue Feb 20 2024 Daniel Garcia <daniel.garcia@suse.com>
- Add python312.patch to fix tests with python3.12
* Tue Aug 18 2020 Matej Cepl <mcepl@suse.com>
- We can finally use %%pyunittest macro
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jul 18 2018 tchvatal@suse.com
- Whitespace in prep phase to ensure we build on Leap 42
* Thu May 31 2018 mcepl@suse.com
- We want to conflict even package called literally python-bugzillatools
  (without any expansions)
* Fri May 25 2018 mcepl@suse.com
- Add upstream patch for porting to Python 3 (and fix some remaining
  bugs)
  * 0001-Working-on-both-2.7-and-3.4.patch patch combining all upstream
    changes to port module to py3k
  * no-bzrlib-py3k.patch my fixes for making test suite working with
    as little fuss as possible
- Adjust SPEC file for adding testing
* Wed May 23 2018 mcepl@suse.com
- Fix SPEC file with spec-cleaner
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue Apr 28 2015 benoit.monin@gmx.fr
- update to version 0.5.5:
  * comment command learned the --private option
  * fix comment enumeration order
  * fix string encoding error when invoking editor which could lead
    to invalid XML being sent to server
- additional changes from version 0.5.4:
  * better error messages on missing server/account configuration
    (#3)
  * remove fields without name data from bug records (#5)
  * make user and password configuration optional (#12)
- additional changes from version 0.5.3.1:
  * fix installation error
- additional changes from version 0.5.3:
  * editor: fix incorrect path to vi(1) when EDITOR is not defined
  * create command: treat "defaulted" fields as mandatory in case
    no default is set
  * ui: fix some unicode encoding errors
  * fields command: handle minor changes in result format in 4.4
  * correct the name of the platform field
    (platform -> rep_platform)
  * expand bzr plugin documentation
- replace README with README.rst: changed upstream
* Mon Oct 21 2013 speilicke@suse.com
- Fix license to GPL-3.0+ (see sr#203363 for reference)
* Wed Oct  9 2013 speilicke@suse.com
- Set license to MIT (according to code).
* Tue Oct  8 2013 speilicke@suse.com
- Initial version
